;; Generated package description from company-statistics.el  -*- no-byte-compile: t -*-
(define-package "company-statistics" "0.2.3" "Sort candidates using completion history" '((emacs "24.3") (company "0.8.5")) :commit "e62157d43b2c874d2edbd547c3bdfb05d0a7ae5c" :authors '(("Ingo Lohmar" . "i.lohmar@gmail.com")) :maintainer '("Ingo Lohmar" . "i.lohmar@gmail.com") :keywords '("abbrev" "convenience" "matching") :url "https://github.com/company-mode/company-statistics")
